==> gradle-8.6-rc-2-src.zip: gradle-8.6-rc-2/platforms/jvm/plugins-java/build.gradle.kts <==
plugins {
    id("gradlebuild.distribution.api-java")
}

description = "Contains the Java plugin, and its supporting classes.  This plugin is used as the basis for building a Java library or application by more specific plugins, and is sometimes applied by other JVM language projects."

dependencies {
    implementation(project(":base-services"))
    implementation(project(":core-api"))
    implementation(project(":core"))
    implementation(project(":dependency-management"))
    implementation(project(":diagnostics"))
    implementation(project(":execution"))
    implementation(project(":file-collections"))
    implementation(project(":language-java"))
    implementation(project(":language-jvm"))
    implementation(project(":logging"))
    implementation(project(":ivy"))
    implementation(project(":maven"))
    implementation(project(":model-core"))
    implementation(project(":platform-base"))
    implementation(project(":platform-jvm"))
    implementation(project(":plugins-java-base"))
    implementation(project(":plugins-jvm-test-suite"))
    implementation(project(":publish"))
    implementation(project(":reporting"))
    implementation(project(":testing-base"))
    implementation(project(":testing-jvm"))
    implementation(project(":test-suites-base"))
    implementation(project(":toolchains-jvm"))

    implementation(libs.ant)
    implementation(libs.commonsLang)
    implementation(libs.groovy)
    implementation(libs.guava)
    implementation(libs.inject)

    testImplementation(testFixtures(project(":core")))

    integTestImplementation(testFixtures(project(":enterprise-operations")))
    integTestImplementation(testFixtures(project(":language-java")))
    integTestImplementation(testFixtures(project(":language-jvm")))
    integTestImplementation(testFixtures(project(":plugins-java-base")))
    integTestImplementation(testFixtures(project(":plugins-jvm-test-fixtures")))
    integTestImplementation(testFixtures(project(":workers")))

    integTestDistributionRuntimeOnly(project(":distributions-jvm"))
}

packageCycles {
    excludePatterns.add("org/gradle/api/plugins/**")
}

==> gradle-8.7-rc-1-src.zip: gradle-8.7-rc-1/platforms/jvm/plugins-java/build.gradle.kts <==
plugins {
    id("gradlebuild.distribution.api-java")
}

description = "Contains the Java plugin, and its supporting classes.  This plugin is used as the basis for building a Java library or application by more specific plugins, and is sometimes applied by other JVM language projects."

dependencies {
    api(project(":core"))
    api(project(":core-api"))
    api(project(":language-java"))
    api(project(":plugins-jvm-test-suite"))
    api(project(":publish"))

    api(libs.inject)

    implementation(project(":base-services"))
    implementation(project(":diagnostics"))
    implementation(project(":execution"))
    implementation(project(":language-jvm"))
    implementation(project(":ivy"))
    implementation(project(":maven"))
    implementation(project(":model-core"))
    implementation(project(":platform-base"))
    implementation(project(":platform-jvm"))
    implementation(project(":plugins-java-base"))
    implementation(project(":testing-jvm"))
    implementation(project(":test-suites-base"))

    runtimeOnly(project(":dependency-management"))
    runtimeOnly(project(":testing-base"))
    runtimeOnly(project(":toolchains-jvm"))

    runtimeOnly(libs.groovy)

    testImplementation(testFixtures(project(":core")))

    integTestImplementation(testFixtures(project(":enterprise-operations")))
    integTestImplementation(testFixtures(project(":language-java")))
    integTestImplementation(testFixtures(project(":language-jvm")))
    integTestImplementation(testFixtures(project(":plugins-java-base")))
    integTestImplementation(testFixtures(project(":plugins-jvm-test-fixtures")))
    integTestImplementation(testFixtures(project(":workers")))

    integTestDistributionRuntimeOnly(project(":distributions-jvm"))
}

packageCycles {
    excludePatterns.add("org/gradle/api/plugins/**")
}
